@@ -33,6 +33,11 @@ from .ecephys.phy.phydatainterface import PhySortingInterface
 from .ecephys.kilosort.kilosortdatainterface import KiloSortSortingInterface
 from .ecephys.edf.edfdatainterface import EDFRecordingInterface
 from .ecephys.tdt.tdtdatainterface import TdtRecordingInterface
+from .ecephys.plexon.plexondatainterface import PlexonRecordingInterface
+from .ecephys.biocam.biocamdatainterface import BiocamRecordingInterface
+from .ecephys.alphaomega.alphaomegadatainterface import AlphaOmegaRecordingInterface
+from .ecephys.mearec.mearecdatainterface import MEArecRecordingInterface
+from .ecephys.mcsraw.mcsrawdatainterface import MCSRawRecordingInterface
 
 # Icephys
 from .icephys.abf.abfdatainterface import AbfInterface
@@ -56,6 +61,10 @@ from .behavior.video.videodatainterface import VideoInterface, MovieInterface
 from .behavior.deeplabcut.deeplabcutdatainterface import DeepLabCutInterface
 from .behavior.sleap.sleapdatainterface import SLEAPInterface
 
+# Text
+from .text.csv.csvtimeintertervalsinterface import CsvTimeIntervalsInterface
+from .text.excel.exceltimeintervalsinterface import ExcelTimeIntervalsInterface
+
 interface_list = [
     # Ecephys
     NeuralynxRecordingInterface,
@@ -84,6 +93,11 @@ interface_list = [
     AxonaUnitRecordingInterface,
     EDFRecordingInterface,
     TdtRecordingInterface,
+    PlexonRecordingInterface,
+    BiocamRecordingInterface,
+    AlphaOmegaRecordingInterface,
+    MEArecRecordingInterface,
+    MCSRawRecordingInterface,
     # Icephys
     AbfInterface,
     # Ophys
@@ -101,4 +115,7 @@ interface_list = [
     VideoInterface,
     DeepLabCutInterface,
     SLEAPInterface,
+    # Text
+    CsvTimeIntervalsInterface,
+    ExcelTimeIntervalsInterface,
 ]
