@@ -1,17 +1,13 @@
 """Authors: Heberto Mayorquin, Cody Baker."""
 from typing import Optional
 
-from spikeinterface.extractors import PhySortingExtractor
-import spikeextractors as se
-
 from ..basesortingextractorinterface import BaseSortingExtractorInterface
 from ....utils import FolderPathType
 
 
 class PhySortingInterface(BaseSortingExtractorInterface):
-    """Primary data interface class for converting a PhySortingExtractor."""
-
-    SX = PhySortingExtractor
+    """Primary data interface class for converting Phy data. Uses
+    :py:class:`~spikeinterface.extractors.PhySortingExtractor`."""
 
     def __init__(
         self,
@@ -21,5 +17,7 @@ class PhySortingInterface(BaseSortingExtractorInterface):
         spikeextractors_backend: bool = False,
     ):
         if spikeextractors_backend:
-            self.SX = se.PhySortingExtractor
+            from spikeextractors import PhySortingExtractor
+
+            self.Extractor = PhySortingExtractor
         super().__init__(folder_path=folder_path, exclude_cluster_groups=exclude_cluster_groups, verbose=verbose)
