@@ -1,5 +1,3 @@
-from roiextractors import Hdf5ImagingExtractor
-
 from ..baseimagingextractorinterface import BaseImagingExtractorInterface
 from ....utils import FilePathType, FloatType, ArrayType
 
@@ -7,8 +5,6 @@ from ....utils import FilePathType, FloatType, ArrayType
 class Hdf5ImagingInterface(BaseImagingExtractorInterface):
     """Data Interface for Hdf5ImagingExtractor."""
 
-    IX = Hdf5ImagingExtractor
-
     def __init__(
         self,
         file_path: FilePathType,
