@@ -1,14 +1,10 @@
-from roiextractors import TiffImagingExtractor
-
 from ..baseimagingextractorinterface import BaseImagingExtractorInterface
-from ....utils import FilePathType, FloatType, ArrayType
+from ....utils import FilePathType, FloatType
 
 
 class TiffImagingInterface(BaseImagingExtractorInterface):
     """Data Interface for TiffImagingExtractor."""
 
-    IX = TiffImagingExtractor
-
     @classmethod
     def get_source_schema(cls):
         source_schema = super().get_source_schema()
